@@ -1,5 +1,4 @@
 from torch import einsum
-from torch.nn import Linear
 
 from backpack.core.derivatives.basederivatives import BaseParameterDerivatives
 
@@ -15,9 +14,6 @@ class LinearDerivatives(BaseParameterDerivatives):
     * i: Input dimension
     """
 
-    def get_module(self):
-        return Linear
-
     def hessian_is_zero(self):
         return True
 
