@@ -1,6 +1,4 @@
-"""
-BackPACK Extensions
-"""
+"""BackPACK extensions that can be passed into a ``with backpack(...)`` context."""
 
 from .curvmatprod import GGNMP, HMP, PCHMP
 from .firstorder import BatchGrad, BatchL2Grad, SumGradSquared, Variance
@@ -9,7 +7,9 @@ from .secondorder import (
     KFAC,
     KFLR,
     KFRA,
-    DiagGGN,
+    BatchDiagGGNExact,
+    BatchDiagGGNMC,
+    BatchDiagHessian,
     DiagGGNExact,
     DiagGGNMC,
     DiagHessian,
@@ -28,7 +28,9 @@ __all__ = [
     "KFRA",
     "HBP",
     "DiagGGNExact",
+    "BatchDiagGGNExact",
     "DiagGGNMC",
-    "DiagGGN",
+    "BatchDiagGGNMC",
     "DiagHessian",
+    "BatchDiagHessian",
 ]
